@@ -1,4 +1,4 @@
-__version__ = "0.2.9"
+__version__ = "0.3.5"
 
 from importlib.util import find_spec
 
@@ -14,11 +14,12 @@ if find_spec("kedro"):
     from .pipeline.sub_pipeline import *  # NOQA
     from .framework.configure import *  # NOQA
     from .framework.context.flexible_context import *  # NOQA
+    from .extras.hooks.add_catalog_dict import *  # NOQA
     from .extras.hooks.add_transformers import *  # NOQA
     from .extras.hooks.mlflow.mlflow_basic_logger import *  # NOQA
     from .extras.hooks.mlflow.mlflow_artifacts_logger import *  # NOQA
     from .extras.hooks.mlflow.mlflow_time_logger import *  # NOQA
-    from .extras.hooks.mlflow.mlflow_outputs_logger import *  # NOQA
+    from .extras.hooks.mlflow.mlflow_datasets_logger import *  # NOQA
     from .extras.transformers.mlflow.mlflow_io_time_logger import *  # NOQA
 
 if find_spec("pandas"):
@@ -26,7 +27,13 @@ if find_spec("pandas"):
     from .extras.datasets.pandas.efficient_csv_local import *  # NOQA
     from .extras.datasets.pandas.pandas_cat_matrix import *  # NOQA
     from .extras.datasets.pandas.pandas_describe import *  # NOQA
-    from .extras.datasets.pandas.histgram import *  # NOQA
+
+    if find_spec("matplotlib"):
+        from .extras.datasets.pandas.histgram import *  # NOQA
+
+        if find_spec("seaborn"):
+
+            from .extras.datasets.seaborn.seaborn_pairplot import *  # NOQA
 
 if find_spec("pandas_profiling"):
     from .extras.datasets.pandas_profiling.pandas_profiling import *  # NOQA
@@ -34,8 +41,6 @@ if find_spec("pandas_profiling"):
 if find_spec("PIL"):
     from .extras.datasets.pillow.images_dataset import *  # NOQA
 
-if find_spec("seaborn"):
-    from .extras.datasets.seaborn.seaborn_pairplot import *  # NOQA
 
 if find_spec("torchvision"):
     from .extras.datasets.torchvision.iterable_images_dataset import *  # NOQA
@@ -46,8 +51,8 @@ if find_spec("cv2"):
 if find_spec("requests"):
     from .extras.datasets.requests.api_dataset import *  # NOQA
 
-if find_spec("httpx"):
-    from .extras.datasets.httpx.async_api_dataset import *  # NOQA
+    if find_spec("httpx"):
+        from .extras.datasets.httpx.async_api_dataset import *  # NOQA
 
 if find_spec("numpy"):
     from .extras.ops.numpy_ops import *  # NOQA
