@@ -11,7 +11,7 @@ class FlexiblePipeline(kedro.pipeline.Pipeline):
         parameters_in_inputs=False,  # type: bool
         module="",  # type: str
         decorator=[],  # type: Union[Callable, List[Callable]]
-        name=None  # type: str
+        **kwargs
     ):
 
         for i, node in enumerate(nodes):
@@ -32,7 +32,17 @@ class FlexiblePipeline(kedro.pipeline.Pipeline):
                         node["inputs"] = inputs + ["parameters"]
 
                 node.setdefault("module", module)
-                node.setdefault("decorator", decorator)
+
+                node.setdefault("decorator", [])
+                if not isinstance(node["decorator"], list):
+                    node["decorator"] = [node["decorator"]]
+
+                decorator = decorator or []
+                if not isinstance(decorator, list):
+                    decorator = [decorator]
+
+                node["decorator"] = decorator + node["decorator"]
+
                 nodes[i] = SubPipeline(**node)
 
-        super().__init__(nodes=nodes, name=name)
+        super().__init__(nodes, **kwargs)
